@@ -79,7 +79,7 @@ get_tournaments <- function(year = 2021, world_tour = TRUE) {
     results <- current_page %>%
       html_nodes("div.darkborder") %>%
       html_nodes("table") %>%
-      .[[2]] %>%
+      .[[1]] %>%
       html_table(header = TRUE) %>%
       as.data.frame() %>%
       clean_names() %>%
@@ -179,8 +179,8 @@ get_tournaments <- function(year = 2021, world_tour = TRUE) {
 #' @return Tibble containing the tournament name, competition category, tournament date, player, seed, nationality, round_reached.
 #'
 #' @examples
-#' ## Who played in the Tournament of Champions in 2020?
-#' \donttest{get_tournament_players(tournament = "tournament of champions", year = 2020)}
+#' ## Who played in the Black Ball Open in 2020?
+#' \donttest{get_tournament_players(tournament = "Black Ball Open", year = 2020)}
 #'
 #' ## Return player registrant data for all PSA World Tour tournaments in 2020
 #' \donttest{get_tournament_players(year = 2020, world_tour = TRUE)}
@@ -222,8 +222,8 @@ get_tournament_players <- function(tournament = NULL, year = 2021, world_tour =
 #' @return Tibble containing the tournament name, competition category, tournament date, round, player 1, player 2, the match winner, games won (by player 1), games lost (by player 1), the match time, player 1's seed, player 2's seed, player 1's nationality, player 2's nationality.
 #'
 #' @examples
-#' ## Return match data for 2020's Tournament of Champions.
-#' \donttest{get_tournament_matches("tournament of champions", year = 2020, world_tour = TRUE)}
+#' ## Return match data for 2020's Black Ball Open.
+#' \donttest{get_tournament_matches("Black Ball Open", year = 2020, world_tour = TRUE)}
 #'
 #' ## Return match data for all PSA World Tour tournaments in 2020
 #' \donttest{get_tournament_matches(year = 2020, world_tour = TRUE)}
@@ -361,8 +361,8 @@ get_tournament_matches <- function(tournament = NULL, year = NULL, world_tour =
 #' @return Tibble containing the tournament name, competition category, tournament date, round, match number, game number, player 1, player 2, the game winner, player 1's score, player 2's score, player 1's seed, player 2's seed, player 1's nationality, player 2's nationality.
 #'
 #' @examples
-#' ## Return game data for 2020's Tournament of Champions.
-#' \donttest{get_tournament_games("tournament of champions", year = 2020, world_tour = TRUE)}
+#' ## Return game data for 2020's Black Ball Open.
+#' \donttest{get_tournament_games("Black Ball Open", year = 2020, world_tour = TRUE)}
 #'
 #' ## Return game data for all PSA World Tour tournaments in 2020
 #' \donttest{get_tournament_games(year = 2020, world_tour = TRUE)}
@@ -413,6 +413,8 @@ get_tournament_games <- function(tournament = NULL, year = NULL, world_tour = NU
 #' @importFrom stringr regex
 #' @importFrom lubridate year
 #' @importFrom lubridate dmy
+#' @importFrom lubridate today
+#' @importFrom lubridate %m-%
 #' @importFrom janitor clean_names
 
 get_tournament_ <- function(tournament = NULL, year = NULL, world_tour = NULL) {
@@ -469,7 +471,7 @@ get_tournament_ <- function(tournament = NULL, year = NULL, world_tour = NULL) {
     results <- current_page %>%
       html_nodes("div.darkborder") %>%
       html_nodes("table") %>%
-      .[[2]] %>%
+      .[[1]] %>%
       html_table(header = TRUE) %>%
       as.data.frame() %>%
       clean_names() %>%
@@ -580,7 +582,8 @@ get_tournament_ <- function(tournament = NULL, year = NULL, world_tour = NULL) {
   if (is.null(tournament) == TRUE) {
 
     tournaments <- tournaments %>%
-      filter(year(date) == year)
+      filter(year(date) == year,
+             date >= lubridate::today() %m-% months(6))
 
   } else if (is.null(year) == TRUE) {
 
