@@ -28,14 +28,14 @@ test_that("test get_tournaments for proper outputs", {
   df <- get_tournaments(year = 2021, world_tour = FALSE)
   expect_is(df, "data.frame")
   expect_is(df, "tbl")
-  expect_equal(length(unique(df$category)), 2)
+  expect_equal(length(unique(na.omit(df$category))), 2)
   expect_is(sample(df$date, 1), "Date")
   expect_equal(year(sample(df$date, 1)), 2021)
 
   df <- get_tournaments(year = 2020, world_tour = TRUE)
   expect_is(df, "data.frame")
   expect_is(df, "tbl")
-  expect_equal(length(unique(df$category)), 2)
+  expect_equal(length(unique(na.omit(df$category))), 2)
   expect_is(sample(df$date, 1), "Date")
   expect_equal(year(sample(df$date, 1)), 2020)
 
